var classIMP_1_1core_1_1ConjugateGradients =
[
    [ "ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html#a95ac65ba3a33dc06fb8616bea22eb7c6", null ],
    [ "~ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html#a1518ccde82fe2d96c6fd3c5540238c1d", null ],
    [ "do_optimize", "classIMP_1_1core_1_1ConjugateGradients.html#af37cb032263f60a83173a5e58e71b2b7", null ],
    [ "get_type_name", "classIMP_1_1core_1_1ConjugateGradients.html#a7693f32e54c2089986a976eed2dc9551", null ],
    [ "get_version_info", "classIMP_1_1core_1_1ConjugateGradients.html#a64567a8c67b546e63d01caee003942f7", null ],
    [ "set_gradient_threshold", "classIMP_1_1core_1_1ConjugateGradients.html#a34dc6e93e506b3c0c6a4bee0fd2ce083", null ],
    [ "set_max_change", "classIMP_1_1core_1_1ConjugateGradients.html#a87348ed65f643bc03d0beab7782a9537", null ]
];